import utilities as util
import simplejson as json
import os
import re

def from_file(filePath):
	if not util.file_readable(filePath):
		return None
	config = Config()
	f = open(filePath, 'r')
	config.read_from_file(f)
	f.close()
	return config

def __read_korporat_conf_file(config, filePath):
	if not util.file_readable(filePath):
		return
	f = open(filePath)
	lineRE = re.compile('(.*)=(.*)')
	for line in f:
		match = lineRE.match(line)
		if not match:
			continue

		confKey = match.group(1)
		if confKey == 'KOR_DATABASE_DIR':
			config.set('dbPath', match.group(2))
		if confKey == 'KOR_PRINTER_NAME':
			config.set('printerName', match.group(2))
	f.close()
	return

def __read_korporat_app_conf_file(config, appName, filePath):
	if not util.file_readable(filePath):
		return
	f = open(filePath)
	for line in f:
		m = re.match('(.+),"([^"]+)".*', line)
		if m:
			config.setAppConfig(appName, m.group(1), m.group(2))
			continue
		m = re.match('(.+),\s*,([+-]?[0-9]+).*', line)
		if m:
			intVal = int(match.group(2))
			config.setAppConfig(appName, m.group(1), intVal)
			continue
		m = re.match('(.+),\s*,\s*,([TF]).*', line)
		if m:
			if m.group(2) == 'T':
				config.setAppConfig(appName, m.group(1), True)
			else:
				config.setAppConfig(appName, m.group(1), False)
			continue
		m = re.match('(.+),\s*,\s*,\s*,([+-]?[0-9.]+).*', line)
		if m:
			try:
				floatVal = float(m.group(2))
				config.setAppConfig(appName, m.group(1), floatVal)
			except ValueError, e:
				pass
			continue

	f.close()
	return

def from_old_conf():
	config = Config()
	__read_korporat_conf_file(config, '/etc/korporat.conf')
	__read_korporat_conf_file(config, os.path.join(os.environ['HOME'], '.korporat', 'korporat.conf'))
	__read_korporat_app_conf_file(config, 'korporat', '/etc/korporat_app.conf')
	__read_korporat_app_conf_file(config, 'korporat', os.path.join(os.environ['HOME'], '.korporat', 'korporat_app.conf'))

	return config

class Config:
	def __init__(self):
		self.data = {}
		self.appData = {}
		self.data['apps'] = self.appData
		return

	def get(self, key):
		if not self.data.has_key(key):
			return None
		return self.data[key]

	def set(self, key, value):
		if key == 'apps':
			return
		self.data[key] = value
		return

	def getAppConfig(self, appName, key):
		if not self.appData.has_key(appName):
			return None
		ac = self.appData[appName]
		if not ac.has_key(key):
			return None
		return ac[key]

	def setAppConfig(self, appName, key, value):
		if not self.appData.has_key(appName):
			self.appData[appName] = {}
		self.appData[appName][key] = value
		return

	def merge(self, other):
		for key in other.data:
			if key == 'apps':
				continue
			self.data[key] = other.data[key]

		if other.appData:
			if not self.appData:
				self.appData = {}
				self.data['apps'] = other.appData

			for appKey in other.appData:
				if not self.appData.has_key(appKey):
					self.appData[appKey] = {}
				for key in other.appData[appKey]:
					self.appData[appKey][key] = other.appData[appKey][key]
		return

	def read_from_file(self, f):
		del self.data
		del self.appData
		self.data = {}

		self.data = util.load_json_file(f)
		if self.data.has_key('apps'):
			self.appData = self.data['apps']
		else:
			self.appData = {}
			self.data['apps'] = self.appData
		return True

	def write_to_file(self, f):
		f.write(json.dumps(self.data, sort_keys=False, indent=4))
		return
