#!/bin/bash

mypath="$(cd "`dirname "$0"`" ; pwd)"

REPOURL="http://repo.pti-cosmetics.com/korporat/pkgs"

WGET=$(which wget)

current_version=$(cat "$mypath/VERSION")
repo_version=$($WGET -q -O- $REPOURL/korporat.VERSION)

if [ -z "$repo_version" ]; then
	echo "Tidak dapat mendapatkan informasi dari server. Cek koneksi internet"
	exit 1
fi

if [ "$current_version" != "$repo_version" ]; then
	wget -O"$mypath/update.tgz" "$REPOURL/korporat-$repo_version.tgz"
	if [ $? -eq 0 ]; then
		# CHECKSUM
		md5=$($WGET -q -O- $REPOURL/korporat-$repo_version.md5sum)
		if [ -z "$md5" ]; then
			echo "Gagal mendapatkan checksum"
			rm -f "$mypath/update.tgz"
			exit 2
		fi
		dlmd5=$(md5sum "$mypath/update.tgz" | awk '{print $1}')
		if [ "x$md5" != "x$dlmd5" ]; then
			echo "Validasi checksum gagal. Ulangi proses update"
			rm -f "$mypath/update.tgz"
			exit 3
		fi
		
		echo "Update sukses. Jalankan kembali program."
	else
		echo "Update gagal. Pastikan koneksi internet dalam keadaan baik."
		rm -f "$mypath/update.tgz"
		exit 2
	fi
fi
